/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.facade.def.dataType;

import java.io.Serializable;

/**
 * XPDL Data Type definition.
 */
public interface DataTypeDefinition extends Serializable {

  /**
   * XPDL Data Type definition.<br>
   * Only BasicType and EnumerationType are supported.<br>
   * See section 7.13 of <a href="http://www.wfmc.org/standards/docs/TC-1025_10_xpdl_102502.pdf">XPDL V1 Specification</a>
   * <ul>
   * <li>Array Type: A fixed size set of data all of the same data type (deprecated).<br></li>
   * <li>Basic Type: A simple type: STRING, INTEGER, FLOAT, DATETIME, REFERENCE, BOOLEAN, or PERFORMER.<br></li>
   * <li>Declared Type: A reference to a data type declared in a TypeDeclaration element.<br></li>
   * <li>Enumeration Type: A set of legal values of a variable or parameter (deprecated).<br></li>
   * <li>ExternalReference: A reference to a type defined in an external document.<br></li>
   * <li>List Type: An unbounded set of data all of the same data type (deprecated).<br></li>
   * <li>Record Type: A set of members that may be of different types (deprecated).<br></li>
   * <li>SchemaType: A data type defined using an XML schema.<br></li>
   * <li>Union Type: A set of members only one of which will be used for an instance of the data (deprecated).<br></li>
   * </ul>
   */
  public static enum Type {
    BasicType, DeclaredType, SchemaType, ExternalReference, RecordType,
    UnionType, EnumerationType, ArrayType, ListType
  }
  /**
   * Returns the {@link Type data type} of the dataField.
   */
  Type getType();
  /**
   * Returns a DataTypeValue interface.
   */
  DataTypeValue getValue();
}


