/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.facade.def.majorElement;

import java.io.Serializable;

import org.ow2.bonita.facade.def.dataType.DataTypeDefinition;
import org.ow2.bonita.facade.uuid.DataFieldDefinitionUUID;

/**
 * This interface represents the DataField definition.
 * It's derived from the DataField Definition (also called Workflow Relevant Data) of XPDL.
 */
public interface DataFieldDefinition extends ProcessDefinitionRecord, Serializable {
  /**
   * Returns the UUID for the DataFieldDefinition.
   */
  DataFieldDefinitionUUID getUUID();
  /**
   * Returns the value of the id attribute of the DataField element defined into the XPDL file.
   */
  String getDataFieldId();
  /**
   * Returns the {@link org.ow2.bonita.facade.def.dataType#DataTypeDefinition} interface.
   */
  DataTypeDefinition getDataType();
  /**
   * Returns the initial value of the dataField.
   */
  String getInitialValue();
  /**
   * Returns the length of the data.
   */
  String getLength();
  /**
   * Returns the description of the dataField.
   */
  String getDescription();
  /**
   * Indicates if it is an array
   */
  boolean isArray();
  /**
   * Indicates if it is an activity dataField.
   */
  boolean isActivityDataField();

}


