/**
 * Copyright (C) 2007  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.facade.exception;

import org.ow2.bonita.facade.uuid.ProcessInstanceUUID;
import org.ow2.bonita.util.BonitaException;

/**
 * Thrown by some methods of the QueryRuntimeAPI and the RuntimeAPI if recorded runtime
 * information for the instance has not been found.
 * @author Marc Blachon, Guillaume Porcher, Charles Souillard, Miguel Valdes, Pierre Vigneras
 */
public class InstanceNotFoundException extends BonitaException {

  private final ProcessInstanceUUID instanceUUID;

  public InstanceNotFoundException(ProcessInstanceUUID instanceUUID) {
    super("Can't find an instance with uuid " + instanceUUID);
    this.instanceUUID = instanceUUID;
  }

  public InstanceNotFoundException(InstanceNotFoundException e) {
    super(e.getMessage());
    this.instanceUUID = e.getInstanceUUID();
  }

  public static InstanceNotFoundException build(Throwable e) {
    if (!(e instanceof InstanceNotFoundException)) {
      throw new BonitaInternalException("Cannot create a InstanceNotFoundException", e);
    }
    return new InstanceNotFoundException((InstanceNotFoundException)e);
  }

  public ProcessInstanceUUID getInstanceUUID() {
    return this.instanceUUID;
  }
}
