package org.ow2.bonita.facade.remote;

import java.rmi.RemoteException;
import java.util.Map;

import org.ow2.bonita.facade.exception.ActivityNotFoundException;
import org.ow2.bonita.facade.exception.IllegalTaskStateException;
import org.ow2.bonita.facade.exception.InstanceNotFoundException;
import org.ow2.bonita.facade.exception.ProcessNotFoundException;
import org.ow2.bonita.facade.exception.TaskNotFoundException;
import org.ow2.bonita.facade.exception.UndeletableInstanceException;
import org.ow2.bonita.facade.exception.VariableNotFoundException;
import org.ow2.bonita.facade.uuid.ActivityInstanceUUID;
import org.ow2.bonita.facade.uuid.ProcessDefinitionUUID;
import org.ow2.bonita.facade.uuid.ProcessInstanceUUID;
import org.ow2.bonita.facade.uuid.TaskUUID;

/**
 * For internal use only.
 */
public interface RemoteRuntimeAPI {

  ProcessInstanceUUID instantiateProcess(ProcessDefinitionUUID processUUID) throws ProcessNotFoundException, RemoteException;

  ProcessInstanceUUID instantiateProcess(ProcessDefinitionUUID processUUID, Map<String, Object> variables)
    throws ProcessNotFoundException, RemoteException;

  void startTask(TaskUUID taskUUID, boolean assignTask) throws TaskNotFoundException, IllegalTaskStateException, RemoteException;

  void finishTask(TaskUUID taskUUID, boolean taskAssign) throws TaskNotFoundException, IllegalTaskStateException, RemoteException;

  void suspendTask(TaskUUID taskUUID, boolean assignTask) throws TaskNotFoundException,
    IllegalTaskStateException, RemoteException;

  void resumeTask(TaskUUID taskUUID, boolean taskAssign) throws TaskNotFoundException,
    IllegalTaskStateException, RemoteException;

  void setProcessInstanceVariable(ProcessInstanceUUID instanceUUID, String variableId, Object variableValue)
    throws InstanceNotFoundException, RemoteException, VariableNotFoundException;

  void setActivityInstanceVariable(ActivityInstanceUUID activityUUID, String variableId,
      Object variableValue) throws ActivityNotFoundException, VariableNotFoundException, RemoteException;

  void deleteProcessInstance(ProcessInstanceUUID instanceUUID) throws InstanceNotFoundException,
    UndeletableInstanceException, RemoteException;

  void deleteAllProcessInstances(ProcessDefinitionUUID processUUID) throws ProcessNotFoundException,
    UndeletableInstanceException, RemoteException;

  void assignTask(TaskUUID taskUUID) throws TaskNotFoundException, RemoteException;
  void assignTask(TaskUUID taskUUID, String actorId) throws TaskNotFoundException, RemoteException;
  void assignTask(TaskUUID taskUUID, java.util.Set<java.lang.String> candidates) throws TaskNotFoundException, RemoteException;

  void setVariable(ActivityInstanceUUID activityUUID, String variableId, Object variableValue)
    throws ActivityNotFoundException, VariableNotFoundException, RemoteException;
}
